@@ -3,6 +3,7 @@
    Virtual File System.
 
    Copyright (C) 1999,2001 Free Software Foundation
+   Copyright (C) 2002 Seth Nickell
 
    The Gnome Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License as
@@ -36,21 +37,36 @@ G_BEGIN_DECLS
 
 typedef GnomeVFSFileSize GnomeVFSInodeNumber;
 
-/* File flags.  */
+/**
+ * GnomeVFSFileFlags:
+ * @GNOME_VFS_FILE_FLAGS_NONE: no flags
+ * @GNOME_VFS_FILE_FLAGS_SYMLINK: whether the file is a symlink.
+ * @GNOME_VFS_FILE_FLAGS_LOCAL: whether the file is on a local filesystem
+ *
+ * Packed boolean bitfield representing special
+ * flags a #GnomeVFSFileInfo struct can have.
+ **/
 typedef enum {
 	GNOME_VFS_FILE_FLAGS_NONE = 0,
-	/* Whether the file is a symlink.  */
 	GNOME_VFS_FILE_FLAGS_SYMLINK = 1 << 0,
-	/* Whether the file is on a local file system.  */
 	GNOME_VFS_FILE_FLAGS_LOCAL = 1 << 1,
 } GnomeVFSFileFlags;
 
-/* Flags indicating what fields in a GnomeVFSFileInfo struct are valid. 
-   Name is always assumed valid (how else would you have gotten a
-   FileInfo struct otherwise?)
- */
-
-/* The file type.  */
+/**
+ * GnomeVFSFileType:
+ * @GNOME_VFS_FILE_TYPE_UNKNOWN:
+ * @GNOME_VFS_FILE_TYPE_REGULAR:
+ * @GNOME_VFS_FILE_TYPE_DIRECTORY:
+ * @GNOME_VFS_FILE_TYPE_FIFO:
+ * @GNOME_VFS_FILE_TYPE_SOCKET:
+ * @GNOME_VFS_FILE_TYPE_CHARACTER_DEVICE:
+ * @GNOME_VFS_FILE_TYPE_BLOCK_DEVICE:
+ * @GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK:
+ *
+ * Enumeration identify the kind of file represented
+ * by a #GnomeVFSFileInfo struct. (note, use of MIME types
+ * is preferred as this field may eventually disappear)
+ **/
 typedef enum {
 	GNOME_VFS_FILE_TYPE_UNKNOWN,
 	GNOME_VFS_FILE_TYPE_REGULAR,
@@ -62,6 +78,29 @@ typedef enum {
 	GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK
 } GnomeVFSFileType;
 
+/**
+ * GnomeVFSFileInfoFields:
+ * @GNOME_VFS_FILE_INFO_FIELDS_NONE: No fields are valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_TYPE: Type field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS: Permissions field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_FLAGS: Flags field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_DEVICE: Device field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_INODE: Inode field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_LINK_COUNT: Link count field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_SIZE: Size field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_BLOCK_COUNT: Block count field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_IO_BLOCK_SIZE: I/O Block Size field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_ATIME: Access time field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_MTIME: Modification time field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_CTIME: Creating time field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_SYMLINK_NAME: Symlink name field is valid
+ * @GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE: Mime type field is valid
+ *
+ * Flags indicating what fields in a GnomeVFSFileInfo struct are valid. 
+ * Name is always assumed valid (how else would you have gotten a
+ * FileInfo struct otherwise?)
+ **/
+
 typedef enum {
 	GNOME_VFS_FILE_INFO_FIELDS_NONE = 0,
 	GNOME_VFS_FILE_INFO_FIELDS_TYPE = 1 << 0,
@@ -77,7 +116,9 @@ typedef enum {
 	GNOME_VFS_FILE_INFO_FIELDS_MTIME = 1 << 10,
 	GNOME_VFS_FILE_INFO_FIELDS_CTIME = 1 << 11,
 	GNOME_VFS_FILE_INFO_FIELDS_SYMLINK_NAME = 1 << 12,
-	GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE = 1 << 13
+	GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE = 1 << 13,
+	GNOME_VFS_FILE_INFO_FIELDS_ACCESS = 1 << 14
+
 } GnomeVFSFileInfoFields;
 
 /* File permissions.  These are the same as the Unix ones, but we wrap them
@@ -105,7 +146,10 @@ typedef enum {
 	GNOME_VFS_PERM_OTHER_READ = S_IROTH,
 	GNOME_VFS_PERM_OTHER_WRITE = S_IWOTH,
 	GNOME_VFS_PERM_OTHER_EXEC = S_IXOTH,
-	GNOME_VFS_PERM_OTHER_ALL = S_IROTH | S_IWOTH | S_IXOTH
+	GNOME_VFS_PERM_OTHER_ALL = S_IROTH | S_IWOTH | S_IXOTH,
+	GNOME_VFS_PERM_ACCESS_READABLE   = 1 << 16,
+	GNOME_VFS_PERM_ACCESS_WRITABLE   = 1 << 17,
+	GNOME_VFS_PERM_ACCESS_EXECUTABLE = 1 << 18
 } GnomeVFSFilePermissions;
 
 
@@ -113,7 +157,7 @@ typedef struct {
 	/* Base name of the file (no path).  */
 	char *name;
 
-	/* Fields which are actually valid in this strcture. */
+	/* Fields which are actually valid in this structure. */
 	GnomeVFSFileInfoFields valid_fields;
 
 	/* File type (i.e. regular, directory, block device...).  */
@@ -169,14 +213,41 @@ typedef struct {
 
 } GnomeVFSFileInfo;
 
+/**
+ * GnomeVFSFileInfoOptions:
+ * @GNOME_VFS_FILE_INFO_DEFAULT: default flags
+ * @GNOME_VFS_FILE_INFO_GET_MIME_TYPE: detect the MIME type
+ * @GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE: only use fast MIME type detection (extensions)
+ * @GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE: force slow MIME type detection where available
+ * (sniffing, algorithmic detection, etc)
+ * @GNOME_VFS_FILE_INFO_FOLLOW_LINKS: automatically follow symbolic links and retrieve the
+ * properties of their target (recommended)
+ *
+ * Packed boolean bitfield representing options that can
+ * be passed into a gnome_vfs_get_file_info() call (or other
+ * related calls that return file info) and affect the operation
+ * of get_file_info.
+ **/
 typedef enum {
 	GNOME_VFS_FILE_INFO_DEFAULT = 0, /* FIXME bugzilla.eazel.com 1203: name sucks */
 	GNOME_VFS_FILE_INFO_GET_MIME_TYPE = 1 << 0,
 	GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE = 1 << 1,
 	GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE = 1 << 2,
-	GNOME_VFS_FILE_INFO_FOLLOW_LINKS = 1 << 3
+	GNOME_VFS_FILE_INFO_FOLLOW_LINKS = 1 << 3,
+	GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS = 1 << 4
 } GnomeVFSFileInfoOptions;
 
+/**
+ * GnomeVFSSetFileInfoMask:
+ * @GNOME_VFS_SET_FILE_INFO_NONE: don't set any file info fields
+ * @GNOME_VFS_SET_FILE_INFO_NAME: change the name
+ * @GNOME_VFS_SET_FILE_INFO_PERMISSIONS: change the permissions
+ * @GNOME_VFS_SET_FILE_INFO_OWNER: change the file's owner
+ * @GNOME_VFS_SET_FILE_INFO_TIME: change the file's time stamp(s)
+ *
+ * Packed boolean bitfield representing the aspects of the file
+ * to be changed in a gnome_vfs_set_file_info() call.
+ **/
 typedef enum {
 	GNOME_VFS_SET_FILE_INFO_NONE = 0,
 	GNOME_VFS_SET_FILE_INFO_NAME = 1 << 0,
@@ -191,40 +262,102 @@ typedef struct {
 	GnomeVFSFileInfo *file_info;
 } GnomeVFSGetFileInfoResult;
 
+/**
+ * GNOME_VFS_FILE_INFO_SYMLINK:
+ * @info: GnomeVFSFileInfo struct
+ *
+ * Determines whether a file is a symbolic link given @info.
+ */
 #define GNOME_VFS_FILE_INFO_SYMLINK(info)		\
 	((info)->flags & GNOME_VFS_FILE_FLAGS_SYMLINK)
 
+/**
+ * GNOME_VFS_FILE_INFO_SET_SYMLINK:
+ * @info: GnomeVFSFileInfo struct
+ * @value: if %TRUE, @info is set to indicate the file is a symbolic link
+ *
+ * Set the symbolic link field in @info to @value.
+ */
 #define GNOME_VFS_FILE_INFO_SET_SYMLINK(info, value)			\
 	(value ? ((info)->flags |= GNOME_VFS_FILE_FLAGS_SYMLINK)	\
 	       : ((info)->flags &= ~GNOME_VFS_FILE_FLAGS_SYMLINK))
 
+/**
+ * GNOME_VFS_FILE_INFO_LOCAL:
+ * @info: GnomeVFSFileInfo struct
+ *
+ * Determines whether a file is local given @info.
+ */
 #define GNOME_VFS_FILE_INFO_LOCAL(info)			\
 	((info)->flags & GNOME_VFS_FILE_FLAGS_LOCAL)
 
+/**
+ * GNOME_VFS_FILE_INFO_SET_LOCAL:
+ * @info: GnomeVFSFileInfo struct
+ * @value: if %TRUE, @info is set to indicate the file is local
+ *
+ * Set the "local file" field in @info to @value.
+ */
 #define GNOME_VFS_FILE_INFO_SET_LOCAL(info, value)			\
 	(value ? ((info)->flags |= GNOME_VFS_FILE_FLAGS_LOCAL)		\
 	       : ((info)->flags &= ~GNOME_VFS_FILE_FLAGS_LOCAL))
 
 
-
+/**
+ * GNOME_VFS_FILE_INFO_SUID:
+ * @info: GnomeVFSFileInfo struct
+ *
+ * Determines whether a file belongs to the super user.
+ */
 #define GNOME_VFS_FILE_INFO_SUID(info)			\
 	((info)->permissions & GNOME_VFS_PERM_SUID)
 
+/**
+ * GNOME_VFS_FILE_INFO_SGID:
+ * @info: GnomeVFSFileInfo struct
+ *
+ * Determines whether a file belongs to the super user's group.
+ */
 #define GNOME_VFS_FILE_INFO_SGID(info)			\
 	((info)->permissions & GNOME_VFS_PERM_SGID)
 
+/**
+ * GNOME_VFS_FILE_INFO_STICKY:
+ * @info: GnomeVFSFileInfo struct
+ *
+ * Determines whether a file has the sticky bit set, given @info
+ */
 #define GNOME_VFS_FILE_INFO_STICKY(info)		\
 	((info)->permissions & GNOME_VFS_PERM_STICKY)
 
-
+/**
+ * GNOME_VFS_FILE_INFO_SET_SUID:
+ * @info: GnomeVFSFileInfo struct
+ * @value: if %TRUE, @info is set to indicate the file belongs to the super user
+ *
+ * Set the SUID field in @info to @value.
+ */
 #define GNOME_VFS_FILE_INFO_SET_SUID(info, value)		\
 	(value ? ((info)->permissions |= GNOME_VFS_PERM_SUID)	\
 	       : ((info)->permissions &= ~GNOME_VFS_PERM_SUID))
 
+/**
+ * GNOME_VFS_FILE_INFO_SET_SGID:
+ * @info: GnomeVFSFileInfo struct
+ * @value: if %TRUE, @info is set to indicate the file belongs to the super user's group
+ *
+ * Set the SGID field in @info to @value.
+ */
 #define GNOME_VFS_FILE_INFO_SET_SGID(info, value)		\
 	(value ? ((info)->permissions |= GNOME_VFS_PERM_SGID)	\
 	       : ((info)->permissions &= ~GNOME_VFS_PERM_SGID))
-
+/**
+ * GNOME_VFS_FILE_INFO_SET_STICKY:
+ * @info: GnomeVFSFileInfo struct
+ * @value: if %TRUE, @info is set to indicate the file has the sticky bit set
+ *
+ * Set the sticky bit in @info to @value.
+ */
 #define GNOME_VFS_FILE_INFO_SET_STICKY(info, value)			\
 	(value ? ((info)->permissions |= GNOME_VFS_PERM_STICKY)		\
 	       : ((info)->permissions &= ~GNOME_VFS_PERM_STICKY))
