@@ -23,6 +23,8 @@
 
 #include <config.h>
 #include "gnome-vfs-handle.h"
+#include "gnome-vfs-handle-private.h"
+#include "gnome-vfs-method.h"
 
 #include <glib/gmessages.h>
 
