@@ -29,6 +29,7 @@
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-handle.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
+#include <libgnomevfs/gnome-vfs-monitor.h>
 
 G_BEGIN_DECLS
 
@@ -73,20 +74,16 @@ GnomeVFSResult	 gnome_vfs_tell			(GnomeVFSHandle *handle,
 
 GnomeVFSResult	 gnome_vfs_get_file_info	(const gchar *text_uri,
 						 GnomeVFSFileInfo *info,
-						 GnomeVFSFileInfoOptions
-						 	options);
+						 GnomeVFSFileInfoOptions options);
 
-GnomeVFSResult	 gnome_vfs_get_file_info_uri
-						(GnomeVFSURI *uri,
+GnomeVFSResult	 gnome_vfs_get_file_info_uri    (GnomeVFSURI *uri,
 						 GnomeVFSFileInfo *info,
-						 GnomeVFSFileInfoOptions
-						        options);
+						 GnomeVFSFileInfoOptions options);
 
 GnomeVFSResult	 gnome_vfs_get_file_info_from_handle
 						(GnomeVFSHandle *handle,
 						 GnomeVFSFileInfo *info,
-						 GnomeVFSFileInfoOptions
-						 	options);
+						 GnomeVFSFileInfoOptions options);
 
 GnomeVFSResult   gnome_vfs_truncate             (const gchar *text_uri,
 						 GnomeVFSFileSize length);
